﻿var ExtractTextPlugin = require("extract-text-webpack-plugin");
var webpack = require("webpack");
var HtmlWebpackPlugin = require("html-webpack-plugin");
var CleanWebpackPlugin = require('clean-webpack-plugin');

module.exports = {
    entry: {
        "polyfills": "./app/polyfills.ts",
        "vendor": "./app/vendor.ts",
        "app": "./app/main.ts",
         "site": [
            "./app/content/css/astra-custom.css",
            "./app/content/css/mdi-prep.css",
            "./app/content/css/opensans.css",
            "./app/content/css/materialdesignicons.css"
        ]
    },
    resolve: {
        extensions: ['', '.ts', '.js', '.json', '.css', '.scss', '.html']
    },
    output: {
        path: "./wwwroot",
        filename: "js/[name]-min.bundle.js",
        publicPath: '../'
    },

    module: {
        loaders: [
            {
                test: /\.ts$/,
                loaders: [
                      "awesome-typescript-loader",
                      "angular2-template-loader",
                      "angular2-router-loader"
                ]
            },
            {
                test: /\.html$/,
                loader: "html"
            },
            {
                test: /\.(png|jpg|gif|ico|woff|woff2|ttf|svg|eot)$/,
                loader: "file?name=images/[name].[ext]"
            },

            // Load css files which are required in vendor.ts
            {
                test: /\.css$/,
                loader: ExtractTextPlugin.extract('style', 'css')
            }
        ]
    },
    plugins: [
        new ExtractTextPlugin("css/[name]-min.bundle.css"),
        new webpack.optimize.CommonsChunkPlugin({
            name: ["app", "vendor", "polyfills"]
        }),

        new webpack.ProvidePlugin({
            jQuery: 'jquery',
            $: 'jquery',
            jquery: 'jquery'
        }),

        new CleanWebpackPlugin(
            [
                "./wwwroot"
            ],
            {
                exclude: [
                  'lib',
                  '_references.js',
                  'favicon.ico'
                ]
            }
        ),

        new webpack.optimize.UglifyJsPlugin({
            compress: {
                warnings: false
            }
        })
         
        // inject in index.html
        //new HtmlWebpackPlugin({
        //    template: "Views/Shared/_Layout.cshtml",
        //    inject: "body", 
        //})
    ],
    devServer: {
        historyApiFallback: true,
        stats: "minimal"
    }
};